
/******************************************************************************

    MODULE
	GetWord.c

    DESCRIPTION
	Get a number and some strings on Commandline
	and write one of them to StdOut

    NOTES
	Kickstart 2.0+ required
	compiles w/ SAS/C v6.51

    BUGS
	none known

    TODO

    EXAMPLES
	> getword 1 x y z
	y

    SEE ALSO

    INDEX

    HISTORY
	01-08-93 b_noll created
	23-08-93 b_noll completed
	11-02-95 b_noll slight changes
	20-02-95 b_noll restructured source
	21-02-95 b_noll added version/format-prefix/offset
	20-03-95 b_noll added args diagnostics

    AUTHOR
	Bernd Noll, Brunnenstrasse 55, D-67661 Kaiserslautern
	b_noll@informatik.uni-kl.de

******************************************************************************/

/**************************************
	    Includes
**************************************/

#ifndef   EXEC_LIBRARIES_H
# include <exec/libraries.h>
#endif /* EXEC_LIBRARIES_H */

#ifndef   CLIB_EXEC_PROTOS_H
# include <clib/exec_protos.h>
#endif /* CLIB_EXEC_PROTOS_H */

#ifndef   DOS_DOS_H
# include <dos/dos.h>
#endif /* DOS_DOS_H */

#ifndef   CLIB_DOS_PROTOS_H
# include <clib/dos_protos.h>
#endif /* CLIB_DOS_PROTOS_H */

#include <proto/dos.h>
#include <proto/exec.h>

/**************************************
	 Defines & Structures
**************************************/

#ifndef ABSEXECBASE
#define ABSEXECBASE ((struct ExecBase **)4L)
#endif

struct _arg {
/* ******************** USER FORMAT ******************** */
#define FORMAT "NUMBER/N/A,WORDS/M"

    LONG  * num;
    STRPTR* words;

/* ******************** USER FORMAT ******************** */
}; /* struct _argv */

#define MAXPATHLEN 256
#define MAXLINELEN 256

#define VERSIONPREFIX	"\0$VER: "
#define VERSIONOFFSET	0
#define FORMATPREFIX	"\0$ARG: "
#define FORMATOFFSET	7

/**************************************
	    Implementation
**************************************/

long _main (void)
{
    const char	  * version = VERSIONPREFIX "GetWord 1.3 " __AMIGADATE__ + VERSIONOFFSET;
    long	    retval  = RETURN_FAIL;
    struct ExecBase*SysBase = *ABSEXECBASE;
    struct Library* DOSBase;

    if (DOSBase = OpenLibrary (DOSNAME, 37)) {
	struct _arg	argv	= { 0 };
	APTR args;
	retval	 = RETURN_ERROR;
	if (args = (void*)ReadArgs(FORMATPREFIX FORMAT + FORMATOFFSET, (LONG*)&argv, NULL)) {
/* ******************** USER BODY ******************** */

	    long num, cnt;

	    for (cnt = 0; argv.words[cnt]; ++cnt);

	    num  = *(argv.num);
	    if (num < 0) num += cnt+1;

	    //retval = RETURN_WARN; /* if no error is wanted ... */

	    if (num == 0 || num > cnt) {
		SetIoErr (ERROR_BAD_NUMBER);
	    } else {
		retval = RETURN_WARN;
		if (PutStr (argv.words[num-1]) == 0) retval = RETURN_OK;
		PutStr("\n");
	    } /* if */


/* ******************** USER BODY ******************** */
	    FreeArgs (args);
	} /* if */

	if (retval > RETURN_WARN)
	    PrintFault(IoErr(), "GetWord");

	CloseLibrary (DOSBase);
    } /* if */
    return (retval);
} /* _main */

/******************************************************************************
*****  END GetWord.c
******************************************************************************/

